@@ -1,6 +1,7 @@
-"""GET endpoints for blaseball /database/ path.
+"""
+Wrappers for the Official Blaseball API
 
-Based off spec: https://github.com/Society-for-Internet-Blaseball-Research/blaseball-api-spec
+https://docs.sibr.dev/docs/apis/reference/Blaseball-API.v1.yaml
 """
 from blaseball_mike.session import session, check_network_response, TIMESTAMP_FORMAT
 from datetime import datetime
@@ -10,6 +11,12 @@ BASE_GITHUB = 'https://raw.githubusercontent.com/xSke/blaseball-site-files/main/
 
 
 def get_global_events(*, cache_time=5):
+    """
+    Get Current Global Events (Ticker Text).
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/globalEvents')
     return check_network_response(res)
@@ -17,7 +24,10 @@ def get_global_events(*, cache_time=5):
 
 def get_all_teams(*, cache_time=5):
     """
-    Returns dictionary keyed by team ID
+    Get All Teams, including Tournament teams and Hall Stars. Returns dictionary keyed by team ID.
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/allTeams')
@@ -26,7 +36,10 @@ def get_all_teams(*, cache_time=5):
 
 def get_all_divisions(*, cache_time=5):
     """
-    Returns dictionary keyed by division ID
+    Get list of all divisions, including removed divisions. Returns dictionary keyed by division ID.
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/allDivisions')
@@ -34,24 +47,52 @@ def get_all_divisions(*, cache_time=5):
 
 
 def get_league(id_='d8545021-e9fc-48a3-af74-48685950a183', cache_time=5):
+    """
+    Get league by ID.
+
+    Args:
+        id_: league ID, defaults to current league (Internet League Blaseball)
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/league?id={id_}')
     return check_network_response(res)
 
 
 def get_subleague(id_, cache_time=5):
+    """
+    Get subleague by ID (eg: Mild, Evil, etc).
+
+    Args:
+        id_: subleague ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/subleague?id={id_}')
     return check_network_response(res)
 
 
 def get_division(id_, cache_time=5):
+    """
+    Get division by ID.
+
+    Args:
+        id_: division ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/division?id={id_}')
     return check_network_response(res)
 
 
 def get_team(id_, cache_time=5):
+    """
+    Get team by ID.
+
+    Args:
+        id_: team ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/team?id={id_}')
     return check_network_response(res)
@@ -59,8 +100,11 @@ def get_team(id_, cache_time=5):
 
 def get_player(id_, cache_time=5):
     """
-    Accepts single string id_, comma separated string, or list.
-    Returns a dictionary with ID as key
+    Get players by ID. Returns a dictionary with player ID as key
+
+    Args:
+        id_: player ID(s). Can be single string id_, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     if len(id_) == 0:
         return {}
@@ -73,8 +117,12 @@ def get_player(id_, cache_time=5):
 
 def get_games(season, day, cache_time=5):
     """
-    Season and day will be 1 indexed.
-    Returns as dictionary with game ID as key.
+    Get games by season and day. Returns as dictionary with game ID as key.
+
+    Args:
+        season: Season, 1 indexed
+        day: Day, 1 indexed
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/games?season={season - 1}&day={day - 1}')
@@ -83,8 +131,12 @@ def get_games(season, day, cache_time=5):
 
 def get_tournament(tournament, day, cache_time=5):
     """
-    Day will be 1 indexed. Tournament is 0 indexed.
-    Returns as dictionary with game ID as key.
+    Get games by tournament and day. Returns as dictionary with game ID as key.
+
+    Args:
+        tournament: Tournament ID
+        day: Day, 1 indexed
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/games?tournament={tournament}&day={day - 1}')
@@ -92,12 +144,25 @@ def get_tournament(tournament, day, cache_time=5):
 
 
 def get_game_by_id(id_, cache_time=5):
+    """
+    Get game by ID.
+
+    Args:
+        id_: game ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/gameById/{id_}')
     return check_network_response(res)
 
 
 def get_offseason_election_details(*, cache_time=5):
+    """
+    Get current Election ballot.
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/offseasonSetup')
     return check_network_response(res)
@@ -105,7 +170,11 @@ def get_offseason_election_details(*, cache_time=5):
 
 def get_offseason_recap(season, cache_time=5):
     """
-    Season will be 1 indexed.
+    Get Election results by season.
+
+    Args:
+        season: Season, 1 indexed
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/offseasonRecap?season={season - 1}')
@@ -114,7 +183,11 @@ def get_offseason_recap(season, cache_time=5):
 
 def get_offseason_bonus_results(id_, cache_time=5):
     """
-    id_ can be a single string ID, comma separated string, or list.
+    Get blessing results by ID.
+
+    Args:
+        id: blessing ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     if isinstance(id_, list):
         id_ = ','.join(id_)
@@ -125,7 +198,11 @@ def get_offseason_bonus_results(id_, cache_time=5):
 
 def get_offseason_decree_results(id_, cache_time=5):
     """
-    id_ can be a single string ID, comma separated string, or list.
+    Get decree results by ID.
+
+    Args:
+        id: blessing ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     if isinstance(id_, list):
         id_ = ','.join(id_)
@@ -135,6 +212,13 @@ def get_offseason_decree_results(id_, cache_time=5):
 
 
 def get_offseason_event_results(id_, cache_time=5):
+    """
+    Get tiding results by ID.
+
+    Args:
+        id: blessing ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     if isinstance(id_, list):
         id_ = ','.join(id_)
     s = session(cache_time)
@@ -144,7 +228,11 @@ def get_offseason_event_results(id_, cache_time=5):
 
 def get_playoff_details(season, cache_time=5):
     """
-    Season will be 1 indexed.
+    Get playoff information by season.
+
+    Args:
+        season: season, 1 indexed.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/playoffs?number={season - 1}')
@@ -152,6 +240,13 @@ def get_playoff_details(season, cache_time=5):
 
 
 def get_playoff_round(id_, cache_time=5):
+    """
+    Get playoff round by ID
+
+    Args:
+        id_: playoff round ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/playoffRound?id={id_}')
     return check_network_response(res)
@@ -159,7 +254,11 @@ def get_playoff_round(id_, cache_time=5):
 
 def get_playoff_matchups(id_, cache_time=5):
     """
-    id_ can be a single string ID, comma separated string, or list.
+    Get playoff matchups (one team vs one team) by ID
+
+    Args:
+        id: playoff matchup ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     if isinstance(id_, list):
         id_ = ','.join(id_)
@@ -169,6 +268,13 @@ def get_playoff_matchups(id_, cache_time=5):
 
 
 def get_standings(id_, cache_time=5):
+    """
+    Get league standings by ID
+
+    Args:
+        id_: standings ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/standings?id={id_}')
     return check_network_response(res)
@@ -176,7 +282,11 @@ def get_standings(id_, cache_time=5):
 
 def get_season(season_number, cache_time=5):
     """
-    Season number is 1 indexed
+    Get season info by season number
+
+    Args:
+        season_number: season, 1 indexed
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/season?number={season_number - 1}')
@@ -184,12 +294,26 @@ def get_season(season_number, cache_time=5):
 
 
 def get_tiebreakers(id, cache_time=5):
+    """
+    Get tiebreakers (Divine Favor) by ID
+
+    Args:
+        id_: tiebreaker ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/tiebreakers?id={id}')
     return {g['id']: g for g in check_network_response(res)}
 
 
 def get_game_statsheets(ids, cache_time=5):
+    """
+    Get statsheets for a game by statsheet ID
+
+    Args:
+        id: game statsheet ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     if isinstance(ids, list):
         ids = ','.join(ids)
     s = session(cache_time)
@@ -198,6 +322,13 @@ def get_game_statsheets(ids, cache_time=5):
 
 
 def get_player_statsheets(ids, cache_time=5):
+    """
+    Get statsheets for a player by statsheet ID
+
+    Args:
+        id: player statsheet ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     if isinstance(ids, list):
         ids = ','.join(ids)
     s = session(cache_time)
@@ -206,6 +337,13 @@ def get_player_statsheets(ids, cache_time=5):
 
 
 def get_season_statsheets(ids, cache_time=5):
+    """
+    Get statsheets for a season by statsheet ID
+
+    Args:
+        id: season statsheet ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     if isinstance(ids, list):
         ids = ','.join(ids)
     s = session(cache_time)
@@ -214,6 +352,13 @@ def get_season_statsheets(ids, cache_time=5):
 
 
 def get_team_statsheets(ids, cache_time=5):
+    """
+    Get statsheets for a team by statsheet ID
+
+    Args:
+        id: team statsheet ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     if isinstance(ids, list):
         ids = ','.join(ids)
     s = session(cache_time)
@@ -222,24 +367,49 @@ def get_team_statsheets(ids, cache_time=5):
 
 
 def get_idols(*, cache_time=5):
+    """
+    Get current Idol board
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get('https://www.blaseball.com/api/getIdols')
     return check_network_response(res)
 
 
 def get_tributes(*, cache_time=5):
+    """
+    Get current Hall of Flame
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get('https://www.blaseball.com/api/getTribute')
     return check_network_response(res)
 
 
 def get_simulation_data(*, cache_time=5):
+    """
+    Get current simulation state
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/simulationData')
     return check_network_response(res)
 
 
 def get_attributes(ids, cache_time=5):
+    """
+    Get modification by ID
+
+    Args:
+        ids: modification ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     if isinstance(ids, list):
         ids = ','.join(ids)
     s = session(cache_time)
@@ -248,6 +418,13 @@ def get_attributes(ids, cache_time=5):
 
 
 def get_items(ids, cache_time=5):
+    """
+    Get item by ID
+
+    Args:
+        ids: item ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     if isinstance(ids, list):
         ids = ','.join(ids)
     s = session(cache_time)
@@ -256,12 +433,26 @@ def get_items(ids, cache_time=5):
 
 
 def get_weather(*, cache_time=5):
+    """
+    Get weather by ID
+
+    Args:
+        ids: weather ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_GITHUB}/weather.json')
     return check_network_response(res)
 
 
 def get_blood(ids, cache_time=5):
+    """
+    Get blood type by ID
+
+    Args:
+        ids: blood ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     if isinstance(ids, list):
         ids = ','.join(ids)
     s = session(cache_time)
@@ -270,6 +461,13 @@ def get_blood(ids, cache_time=5):
 
 
 def get_coffee(ids, cache_time=5):
+    """
+    Get coffee preference by ID
+
+    Args:
+        ids: coffee ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     if isinstance(ids, list):
         ids = ','.join(ids)
     s = session(cache_time)
@@ -277,7 +475,7 @@ def get_coffee(ids, cache_time=5):
     return check_network_response(res)
 
 
-def get_feed_global(limit=50, sort=None, category=None, start=None, type_=None, cache_time=5):
+def get_feed_global(limit=50, sort=None, category=None, start=None, type_=None, season=None, cache_time=5):
     """
     Get Global Feed
 
@@ -287,6 +485,7 @@ def get_feed_global(limit=50, sort=None, category=None, start=None, type_=None,
         category: 0 - Game, 1 - Changes, 2 - Abilities, 3 - Outcomes, 4 - Narrative
         start: timestamp
         type_: event type ID
+        season: season, 1-indexed
         cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     if isinstance(start, datetime):
@@ -301,6 +500,8 @@ def get_feed_global(limit=50, sort=None, category=None, start=None, type_=None,
         params["start"] = start
     if type_ is not None:
         params["type"] = type_
+    if season is not None:
+        params["season"] = season - 1
 
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/feed/global', params=params)
@@ -338,7 +539,7 @@ def get_feed_game(id_, limit=50, sort=None, category=None, start=None, type_=Non
     return check_network_response(res)
 
 
-def get_feed_team(id_, limit=50, sort=None, category=None, start=None, type_=None, cache_time=5):
+def get_feed_team(id_, limit=50, sort=None, category=None, start=None, type_=None, season=None, cache_time=5):
     """
     Get Team Feed
 
@@ -349,6 +550,7 @@ def get_feed_team(id_, limit=50, sort=None, category=None, start=None, type_=Non
         category: 0 - Game, 1 - Changes, 2 - Abilities, 3 - Outcomes, 4 - Narrative
         start: timestamp
         type_: event type ID
+        season: 1-indexed
         cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     if isinstance(start, datetime):
@@ -363,13 +565,15 @@ def get_feed_team(id_, limit=50, sort=None, category=None, start=None, type_=Non
         params["start"] = start
     if type_ is not None:
         params["type"] = type_
+    if season is not None:
+        params["season"] = season - 1
 
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/feed/team', params=params)
     return check_network_response(res)
 
 
-def get_feed_player(id_, limit=50, sort=None, category=None, start=None, type_=None, cache_time=5):
+def get_feed_player(id_, limit=50, sort=None, category=None, start=None, type_=None, season=None, cache_time=5):
     """
     Get Player Feed
 
@@ -380,6 +584,7 @@ def get_feed_player(id_, limit=50, sort=None, category=None, start=None, type_=N
         category: 0 - Game, 1 - Changes, 2 - Abilities, 3 - Outcomes, 4 - Narrative
         start: timestamp
         type_: event type ID
+        season: season, 1-indexed
         cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     if isinstance(start, datetime):
@@ -394,6 +599,8 @@ def get_feed_player(id_, limit=50, sort=None, category=None, start=None, type_=N
         params["start"] = start
     if type_ is not None:
         params["type"] = type_
+    if season is not None:
+        params["season"] = season - 1
 
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/feed/player', params=params)
@@ -403,6 +610,11 @@ def get_feed_player(id_, limit=50, sort=None, category=None, start=None, type_=N
 def get_feed_phase(season, phase, cache_time=5):
     """
     Get Feed by Phase
+
+    Args:
+        season: season, 1 indexed
+        phase: sim phase number
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
     """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/feedbyphase?season={season-1}&phase={phase}')
@@ -410,12 +622,26 @@ def get_feed_phase(season, phase, cache_time=5):
 
 
 def get_feed_story(id_, cache_time=5):
+    """
+    Get Feed story item by ID
+
+    Args:
+        id_: Event ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/feed/story?id={id_}')
     return check_network_response(res)
 
 
 def get_renovations(ids, cache_time=5):
+    """
+    Get stadium renovation by ID
+
+    Args:
+        ids: renovation ID(s). Can be a single string ID, comma separated string, or list.
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     if isinstance(ids, list):
         ids = ','.join(ids)
     s = session(cache_time)
@@ -424,48 +650,124 @@ def get_renovations(ids, cache_time=5):
 
 
 def get_renovation_progress(id_, cache_time=5):
+    """
+    Get stadium renovation progress by stadium ID
+
+    Args:
+        id_: stadium ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/renovationProgress?id={id_}')
     return check_network_response(res)
 
 
 def get_season_day_count(season, cache_time=5):
+    """
+    Get number of days in a season, by season
+
+    Args:
+        season: season, 1 indexed
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/seasondaycount?season={season - 1}')
     return check_network_response(res)
 
 
 def get_team_election_stats(team_id, cache_time=5):
+    """
+    Get will contribution percentage by team ID
+
+    Args:
+        team_id: team ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/teamElectionStats?id={team_id}')
     return check_network_response(res)
 
 
 def get_previous_champ(*, cache_time=5):
+    """
+    Get winner of previous championship
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/getPreviousChamp')
     return check_network_response(res)
 
 
 def get_community_chest_progress(*, cache_time=5):
+    """
+    Get current progress to community chest opening
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/communityChestProgress')
     return check_network_response(res)
 
 
 def get_players_by_item(item, cache_time=5):
+    """
+    Get player holding an item
+
+    Args:
+        item: item ID
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/playersByItemId?id={item}')
     return check_network_response(res)
 
 
 def get_gift_progress(*, cache_time=5):
+    """
+    Get league-wide gift shop progress
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/giftProgress')
     return check_network_response(res)
 
 
 def get_all_players(*, cache_time=5):
+    """
+    Get list of player names and IDs
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
     s = session(cache_time)
     res = s.get(f'{BASE_URL}/playerNamesIds')
     return check_network_response(res)
+
+
+def get_store_info(*, cache_time=5):
+    """
+    Get menu, price, and payout info for the Store
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
+    s = session(cache_time)
+    res = s.get(f'{BASE_URL}/shopSetup')
+    return check_network_response(res)
+
+
+def get_sunsun_info(*, cache_time=5):
+    """
+    Get information about the status of Sun(Sun) (pressure)
+
+    Args:
+        cache_time: response cache lifetime in seconds, or `None` for infinite cache
+    """
+    s = session(cache_time)
+    res = s.get(f'{BASE_URL}/sunsun')
+    return check_network_response(res)
